@@ -8,7 +8,7 @@ from .models import TokenInterlocutorConnection
 class TokenInterlocutorConnectionAdmin(admin.ModelAdmin):
     list_display = (
         'id',
-        'get_device', 'get_os', 'get_app',
+        'get_users', 'get_device', 'get_os', 'get_app',
         'interlocutor', 'token', 'created_at',
     )
     date_hierarchy = 'created_at'
@@ -25,6 +25,22 @@ class TokenInterlocutorConnectionAdmin(admin.ModelAdmin):
         'token__user_connections__user__username',
     )
 
+    def get_queryset(self, request):
+        return (
+            super().get_queryset(request)
+            .prefetch_related(
+                'token__user_connections',
+                'token__user_connections__user',
+            )
+        )
+
+    def get_users(self, obj):
+        if not obj.token_id:
+            return ''
+
+        return ', '.join(str(x.user) for x in obj.token.user_connections.all())
+    get_users.short_description = pgettext_lazy('wcd_jwt', 'Users')
+
     def get_device(self, obj):
         return obj.interlocutor.device
     get_device.short_description = pgettext_lazy('wcd_jwt', 'Device')
