@@ -13,7 +13,7 @@ def connect(
     network: Optional[InterlocutorNetwork] = None,
 ) -> List[TokenInterlocutorConnection]:
     connections = model_bulk_get_or_create(TokenInterlocutorConnection, [
-        ({'interlocutor': interlocutor, 'network': network, 'token': token}, {})
+        ({'token': token}, {'interlocutor': interlocutor, 'network': network})
         for token in tokens
     ])
 
